@@ -248,7 +248,6 @@
 #include "etc/cling/Interpreter/RuntimeOptions.h"
 #include "etc/cling/Interpreter/Value.h"
 #include "etc/cling/Interpreter/Visibility.h"
-#define ROOFIT_BUILDS_ITSELF
 // ./math/mathmore/G__MathMore.cxx
 #include "Math/ChebyshevApprox.h"
 #include "Math/Derivator.h"
@@ -379,7 +378,6 @@
 #include "Math/SpecFuncMathCore.h"
 #include "Math/StdEngine.h"
 #include "Math/TDataPoint.h"
-#include "Math/TDataPointN.h"
 #include "Math/TRandomEngine.h"
 #include "Math/Types.h"
 #include "Math/Util.h"
@@ -593,7 +591,6 @@
 #include "Minuit2/ExternalInternalGradientCalculator.h"
 #include "Minuit2/FCNAdapter.h"
 #include "Minuit2/FCNBase.h"
-#include "Minuit2/FCNGradAdapter.h"
 #include "Minuit2/FCNGradientBase.h"
 #include "Minuit2/FumiliBuilder.h"
 #include "Minuit2/FumiliChi2FCN.h"
@@ -640,16 +637,16 @@
 #include "Minuit2/MnMinos.h"
 #include "Minuit2/MnParabola.h"
 #include "Minuit2/MnParabolaFactory.h"
-#include "Minuit2/MnParabolaPoint.h"
 #include "Minuit2/MnParameterScan.h"
+#include "Minuit2/MnParameterTransformation.h"
 #include "Minuit2/MnPlot.h"
+#include "Minuit2/MnPoint.h"
 #include "Minuit2/MnPosDef.h"
 #include "Minuit2/MnPrint.h"
 #include "Minuit2/MnScan.h"
 #include "Minuit2/MnSeedGenerator.h"
 #include "Minuit2/MnSimplex.h"
 #include "Minuit2/MnStrategy.h"
-#include "Minuit2/MnTiny.h"
 #include "Minuit2/MnTraceObject.h"
 #include "Minuit2/MnUserCovariance.h"
 #include "Minuit2/MnUserFcn.h"
@@ -667,9 +664,6 @@
 #include "Minuit2/SimplexMinimizer.h"
 #include "Minuit2/SimplexParameters.h"
 #include "Minuit2/SimplexSeedGenerator.h"
-#include "Minuit2/SinParameterTransformation.h"
-#include "Minuit2/SqrtLowParameterTransformation.h"
-#include "Minuit2/SqrtUpParameterTransformation.h"
 #include "Minuit2/VariableMetricBuilder.h"
 #include "Minuit2/VariableMetricEDMEstimator.h"
 #include "Minuit2/VariableMetricMinimizer.h"
@@ -776,6 +770,7 @@
 #include "RooFunctor1DBinding.h"
 #include "RooFunctorBinding.h"
 #include "RooGamma.h"
+#include "RooGaussExpTails.h"
 #include "RooGaussian.h"
 #include "RooGaussModel.h"
 #include "RooGExpModel.h"
@@ -885,6 +880,7 @@
 #include "RooEllipse.h"
 #include "RooErrorHandler.h"
 #include "RooErrorVar.h"
+#include "RooEvaluatorWrapper.h"
 #include "RooExpensiveObjectCache.h"
 #include "RooExtendPdf.h"
 #include "RooExtendedBinding.h"
@@ -919,7 +915,6 @@
 #include "RooFitResult.h"
 #include "RooFormulaVar.h"
 #include "RooFracRemainder.h"
-#include "RooFuncWrapper.h"
 #include "RooFunctor.h"
 #include "RooGenContext.h"
 #include "RooGenFitStudy.h"
@@ -945,6 +940,8 @@
 #include "RooMoment.h"
 #include "RooMsgService.h"
 #include "RooMultiCategory.h"
+#include "RooMultiPdf.h"
+#include "RooMultiReal.h"
 #include "RooMultiVarGaussian.h"
 #include "RooNameReg.h"
 #include "RooNormSetCache.h"
@@ -1025,7 +1022,6 @@
 #include "RooStats/FeldmanCousins.h"
 #include "RooStats/FrequentistCalculator.h"
 #include "RooStats/Heaviside.h"
-#include "RooStats/HLFactory.h"
 #include "RooStats/HybridCalculator.h"
 #include "RooStats/HybridPlot.h"
 #include "RooStats/HybridResult.h"
@@ -1087,6 +1083,8 @@
 // ./roofit/codegen/G__RooFitCodegen.cxx
 #include "RooFit/CodegenImpl.h"
 // ./io/io/G__RIO.cxx
+#include "ROOT/RConcurrentHashColl.hxx"
+#include "ROOT/RFile.hxx"
 #include "ROOT/RRawFile.hxx"
 #include "ROOT/RRawFileTFile.hxx"
 #include "ROOT/RRawFileUnix.hxx"
@@ -1351,6 +1349,7 @@
 #include "TMVA/BatchGenerator/RBatchGenerator.hxx"
 #include "TMVA/BatchGenerator/RBatchLoader.hxx"
 #include "TMVA/BatchGenerator/RChunkLoader.hxx"
+#include "TMVA/BatchGenerator/RChunkConstructor.hxx"
 // ./tmva/pymva/G__PyMVA.cxx
 #include "TMVA/MethodPyAdaBoost.h"
 #include "TMVA/MethodPyGTB.h"
@@ -1404,6 +1403,20 @@
 #include "TGraphPainter.h"
 #include "THistPainter.h"
 #include "TPaletteAxis.h"
+// ./hist/histv7/G__ROOTHist.cxx
+#include "ROOT/RAxes.hxx"
+#include "ROOT/RBinIndex.hxx"
+#include "ROOT/RBinIndexRange.hxx"
+#include "ROOT/RBinWithError.hxx"
+#include "ROOT/RCategoricalAxis.hxx"
+#include "ROOT/RHist.hxx"
+#include "ROOT/RHistEngine.hxx"
+#include "ROOT/RHistStats.hxx"
+#include "ROOT/RHistUtils.hxx"
+#include "ROOT/RLinearizedIndex.hxx"
+#include "ROOT/RRegularAxis.hxx"
+#include "ROOT/RVariableBinAxis.hxx"
+#include "ROOT/RWeight.hxx"
 // ./hist/spectrumpainter/G__SpectrumPainter.cxx
 #include "TSpectrum2Painter.h"
 // ./hist/hist/G__Hist.cxx
@@ -1440,6 +1453,7 @@
 #include "TGraphSmooth.h"
 #include "TGraphTime.h"
 #include "TScatter.h"
+#include "TScatter2D.h"
 #include "TH1C.h"
 #include "TH1D.h"
 #include "TH1F.h"
@@ -1533,7 +1547,9 @@
 #include "ROOT/RNTupleReadOptions.hxx"
 #include "ROOT/RNTupleReader.hxx"
 #include "ROOT/RNTupleSerialize.hxx"
+#include "ROOT/RNTupleTypes.hxx"
 #include "ROOT/RNTupleUtil.hxx"
+#include "ROOT/RNTupleUtils.hxx"
 #include "ROOT/RNTupleView.hxx"
 #include "ROOT/RNTupleWriteOptions.hxx"
 #include "ROOT/RNTupleWriteOptionsDaos.hxx"
@@ -1597,7 +1613,6 @@
 #include "TLeafS.h"
 #include "TNtupleD.h"
 #include "TNtuple.h"
-#include "TQueryResult.h"
 #include "TreeUtils.h"
 #include "TSelector.h"
 #include "TSelectorList.h"
@@ -1670,6 +1685,7 @@
 #include "ROOT/RDF/InterfaceUtils.hxx"
 #include "ROOT/RDF/RActionBase.hxx"
 #include "ROOT/RDF/RAction.hxx"
+#include "ROOT/RDF/RActionSnapshot.hxx"
 #include "ROOT/RDF/RActionImpl.hxx"
 #include "ROOT/RDF/RColumnRegister.hxx"
 #include "ROOT/RDF/RNewSampleNotifier.hxx"
@@ -1708,6 +1724,7 @@
 #include "ROOT/RDF/RVariationReader.hxx"
 #include "ROOT/RDF/RVariationsDescription.hxx"
 #include "ROOT/RDF/RVariedAction.hxx"
+#include "ROOT/RDF/SnapshotHelpers.hxx"
 #include "ROOT/RDF/Utils.hxx"
 #include "ROOT/RDF/PyROOTHelpers.hxx"
 #include "ROOT/RDF/RDFDescription.hxx"
@@ -1719,6 +1736,11 @@
 #include "ROOT/RNTupleInspector.hxx"
 // ./tree/webviewer/G__ROOTTreeViewer.cxx
 #include "ROOT/RTreeViewer.hxx"
+// ./tree/ntuplebrowse/G__ROOTNTupleBrowse.cxx
+#include "ROOT/RNTupleBrowseUtils.hxx"
+#include "ROOT/RNTupleClassicBrowse.hxx"
+#include "ROOT/RNTupleDrawVisitor.hxx"
+#include "ROOT/RNTupleTreeMap.hxx"
 // ./graf2d/x11/G__GX11.cxx
 #include "TGX11.h"
 // ./graf2d/graf/G__Graf.cxx
@@ -1971,6 +1993,9 @@
 #include "TFitEditor.h"
 #include "TFitParametersDialog.h"
 #include "TTreeInput.h"
+// ./gui/treemap/G__ROOTTreeMap.cxx
+#include "ROOT/RTreeMapBase.hxx"
+#include "ROOT/RTreeMapPainter.hxx"
 // ./gui/gui/G__Gui.cxx
 #include "HelpText.h"
 #include "TG3DLine.h"
@@ -2083,7 +2108,6 @@
 #include "TThread.h"
 #include "TThreadImp.h"
 #include "TThreadPool.h"
-#include "ROOT/RConcurrentHashColl.hxx"
 #include "ROOT/TRWSpinLock.hxx"
 #include "ROOT/TSpinMutex.hxx"
 #include "ROOT/TThreadedObject.hxx"
